@@ -14,7 +14,8 @@
 # You should have received a copy of the Artistic License along with this
 # program.  If not, see <http://www.perlfoundation.org/artistic_license_2_0>.
 #
-package Graphics::Fig::Ellipse 1.0;
+use 5.014;
+package Graphics::Fig::Ellipse v1.0.1;
 use strict;
 use warnings;
 use Carp;
